@@ -24,7 +24,15 @@ var searchData=
   ['openmpt_5fmodule_5fcreate_5ffrom_5fmemory',['openmpt_module_create_from_memory',['../group__libopenmpt__c.html#ga53377a365f001a99ae4626918e55b25e',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fcreate_5ffrom_5fmemory2',['openmpt_module_create_from_memory2',['../group__libopenmpt__c.html#ga8237a4d9dfb0f33c7cd0a2926f30a25f',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fctl_5fget',['openmpt_module_ctl_get',['../group__libopenmpt__c.html#ga20d871022840893e6f4cb13ad78a0ff7',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fget_5fboolean',['openmpt_module_ctl_get_boolean',['../group__libopenmpt__c.html#ga79c1fc512437220d9f65556723326c78',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fget_5ffloatingpoint',['openmpt_module_ctl_get_floatingpoint',['../group__libopenmpt__c.html#gac6e1f6ec3d9cc82fa3df5e63dc5b5350',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fget_5finteger',['openmpt_module_ctl_get_integer',['../group__libopenmpt__c.html#gab4cd78a172569a5d02c4e41c3caac18c',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fget_5ftext',['openmpt_module_ctl_get_text',['../group__libopenmpt__c.html#ga13b040e57fd61854766b3d3fdca14b3a',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fctl_5fset',['openmpt_module_ctl_set',['../group__libopenmpt__c.html#ga384de8fb7266821e7a3677460861593e',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fset_5fboolean',['openmpt_module_ctl_set_boolean',['../group__libopenmpt__c.html#gab178566ca8e2280f4389370200b00ad5',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fset_5ffloatingpoint',['openmpt_module_ctl_set_floatingpoint',['../group__libopenmpt__c.html#ga7af8284475e3411b25d3f8c9686b02e6',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fset_5finteger',['openmpt_module_ctl_set_integer',['../group__libopenmpt__c.html#ga6a3990be4d7140e255fbc96e1eaed3db',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fctl_5fset_5ftext',['openmpt_module_ctl_set_text',['../group__libopenmpt__c.html#ga8a4b646f940bd9e9527dbda4edbeca17',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fdestroy',['openmpt_module_destroy',['../group__libopenmpt__c.html#ga40d27bb0ef054c3cd5e7ae3e85ed64e1',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5ferror_5fclear',['openmpt_module_error_clear',['../group__libopenmpt__c.html#gaceaa2675b539674c1611d1e8a392aa87',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5ferror_5fget_5flast',['openmpt_module_error_get_last',['../group__libopenmpt__c.html#ga7ffc363899565eebe05d38a670050c83',1,'libopenmpt.h']]],
@@ -44,6 +52,7 @@ var searchData=
   ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5frear_5fleft',['openmpt_module_get_current_channel_vu_rear_left',['../group__libopenmpt__c.html#ga3c5d64718d0d574bf94bd9f13aa3b8a1',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5frear_5fright',['openmpt_module_get_current_channel_vu_rear_right',['../group__libopenmpt__c.html#ga459facd9def73d056190a76882da29b6',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fget_5fcurrent_5fchannel_5fvu_5fright',['openmpt_module_get_current_channel_vu_right',['../group__libopenmpt__c.html#gab90660d5d9fa932cfff118023c4b56c8',1,'libopenmpt.h']]],
+  ['openmpt_5fmodule_5fget_5fcurrent_5festimated_5fbpm',['openmpt_module_get_current_estimated_bpm',['../group__libopenmpt__c.html#gae3ed09be74bd9e5dc78d424608a17e72',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fget_5fcurrent_5forder',['openmpt_module_get_current_order',['../group__libopenmpt__c.html#ga88bd245db9a3e857443920bf68f093a6',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fget_5fcurrent_5fpattern',['openmpt_module_get_current_pattern',['../group__libopenmpt__c.html#ga9f2013da0ddda5888d8ac9821193c269',1,'libopenmpt.h']]],
   ['openmpt_5fmodule_5fget_5fcurrent_5fplaying_5fchannels',['openmpt_module_get_current_playing_channels',['../group__libopenmpt__c.html#ga145570605cff14c147d096e93bd16dbc',1,'libopenmpt.h']]],
